@@ -330,18 +330,21 @@ GDAL.close <- function(dataset) {
             isTrans <- is(dataset, "GDALTransientDataset")
             if (isTrans) {
                 if (isObjPtrNULL(dataset)) stop("object already closed")
-                filename <- getDescription(dataset)
+#                filename <- getDescription(dataset)
             }
             .setCollectorFun(slot(dataset, 'handle'), NULL)
             .Call('RGDAL_CloseDataset', dataset, PACKAGE="rgdal")
-            if (isTrans) {
-                basen <- basename(filename)
-                dirn <- dirname(filename)
-                lf <- list.files(path=dirn, pattern=basen)
-                flf <- paste(dirn, lf, sep="/")
-                unlink(flf)
-            }
-            invisible(gc())
+#            .Call("RGDAL_CloseHandle", slot(dataset, 'handle'),
+#                PACKAGE="rgdal")
+             invisible(NULL)
+#            if (isTrans) {
+#                basen <- basename(filename)
+#                dirn <- dirname(filename)
+#                lf <- list.files(path=dirn, pattern=basen)
+#                flf <- paste(dirn, lf, sep="/")
+#                unlink(flf)
+#            }
+#            invisible(gc())
 }
 
 setMethod('dim', 'GDALReadOnlyDataset',
@@ -715,54 +718,6 @@ getRasterBlockSize <- function(raster) {
   
 }
 
-# thin wrappers 121001 Robert J. Hijmans
-
-.gd_SetNoDataValue <- function(object, NAflag) {
-.Call("RGDAL_SetNoDataValue", object, as.double(NAflag), PACKAGE="rgdal")
-}
-
-
-.gd_SetGeoTransform <- function(object, geotrans) {
-   .Call("RGDAL_SetGeoTransform", object, geotrans, PACKAGE="rgdal")
-}
-
-
-.gd_SetProject <- function(object, proj4string) {
-    .Call("RGDAL_SetProject", object, proj4string, PACKAGE="rgdal")
-}
-
-
-.gd_SetStatistics <- function(object, statistics) {
-.Call("RGDAL_SetStatistics", object, as.double(statistics), PACKAGE="rgdal")
-}
-
-.gd_SetRasterColorTable <- function(object, icT) {
-    if (!is.matrix(icT)) {
-        stopifnot(is.character(icT))
-        icT <- t(col2rgb(icT))
-    }
-    stopifnot(is.matrix(icT))
-    stopifnot(storage.mode(icT) == "integer")
-    ricT <- nrow(icT)
-    cicT <- ncol(icT)
-    stopifnot(cicT == 3 || cicT == 4)
-    .Call("RGDAL_SetRasterColorTable", object, icT, ricT, cicT,
-        PACKAGE = "rgdal")
-}
-
-.gd_SetCategoryNames <- function(object, icN) {
-    stopifnot(is.character(icN))
-    .Call("RGDAL_SetCategoryNames", object, icN, PACKAGE = "rgdal")
-}
-
-
-.gd_transform <- function(projfrom, projto, n, x, y, z=NULL) {
-  if (is.null(z)) .Call("transform", projfrom, projto, n, x, y, NULL,
-      PACKAGE="rgdal")
-  else .Call("transform", projfrom, projto, n, x, y, z,
-      PACKAGE="rgdal")
-}
-
 get_OVERRIDE_PROJ_DATUM_WITH_TOWGS84 <- function() {
   get("OVERRIDE_PROJ_DATUM_WITH_TOWGS84", envir=.RGDAL_CACHE)
 }
